****************************************************************
***THIS FILE GENERATES THE TWO DATASETS USED IN GERBER ET AL.***
****************************************************************

clear all
set mem 700m
set more 1

**** MECHANICAL TURK
use "..\not_public\final_mturk_data.dta", clear
*drop cases where TIPI (randomly) adminstered after treatment
gen tipi_late=(tipi_placement=="TIPI Late")
label var tipi_late "TIPI post-stimulus (1=yes)"
drop if tipi_late==1

tab treatment, gen(trt_)
rename trt_1 control
label var control "Control Group (1=yes)"
*drop unused conditions (conflict, social proof stuff)
drop if trt_3==1
drop if trt_4==1
drop if trt_9==1
drop if trt_10==1
*collapse conditions with same message but varied attractiveness image pairings
gen trt_duty=trt_2+trt_7+trt_8
rename trt_5 trt_socialpressure
rename trt_6 trt_instrumental
label var trt_duty "Treatment: Civic Duty (1=yes)"
label var trt_socialpressure "Treatment: Social Pressure (1=yes)"
label var trt_instrumental "Treatment: Instrumental Benefits (1=yes)"

keep control trt_duty trt_socialpressure trt_instrumental country consent tipi1a tipi2a tipi3a tipi4a tipi5a tipi6a tipi7a tipi8a tipi9a tipi10a regvote turnout08 pid_stem pid_other pid_dstr pid_rstr pid_lean ideology turnout_intent yearofbirth education income r_white r_black r_hispanic r_asian r_nativeamer r_mixed r_other gender
save "mturk_replication.dta", replace


***** FIELD EXPERIMENT DATASET BUILD
**GENERATE TURNOUT VARIABLES (COMMENTED OUT TO SAVE COMPUTER TIME)

use "..\not_public\grebnerVH.dta", clear
foreach i in g p {
gen `i'2008=0
gen `i'2006=0
gen `i'2004=0
gen `i'2002=0
replace `i'2008=1 if subinstr(`i',"I","",.)!=`i'
replace `i'2006=1 if subinstr(`i',"G","",.)!=`i'
replace `i'2004=1 if subinstr(`i',"E","",.)!=`i'
replace `i'2002=1 if subinstr(`i',"C","",.)!=`i'
}
label var g2008 "Turnout 2008 - General"
label var p2008 "Turnout 2008 - Primary"
label var g2006 "Turnout 2006 - General"
label var p2006 "Turnout 2006 - Primary"
label var g2004 "Turnout 2004 - General"
label var p2004 "Turnout 2004 - Primary"
label var g2002 "Turnout 2002 - General"
label var p2002 "Turnout 2002 - Primary"
sort id 
save "..\not_public\grebnerVHindicators.dta", replace


*** STARTING SAMPLE FILE, KEEP ONLY CASES THAT WE SENT TO MOUNTAIN WEST 
use "..\not_public\sample.dta", clear
keep if sample2==1
save "..\not_public\sampleOnly.dta", replace

*** STRIP ETOV TO ID, 2006 Primary TURNOUT, and GREBNER MEASURES USED TO DETERMINE ELIGIBILITY
use "..\not_public\NotAnon2006.dta", clear
sort hh_id
gen c7_other=p2004[_n-1] if hh_id[_n-1]==hh_id
replace c7_other=p2004[_n+1] if hh_id[_n+1]==hh_id
rename hh_id hh_id_orig
rename hh_size hh_size_orig
label var c7_other "Other HH-Member TO Primary 2004"
keep id vt_aug06 yob hh_id_orig hh_size_orig c7_other dem aug av
sort id 
save "..\not_public\etovVH.dta", replace

* MATCH SURVEY DATA TO ETOV SAMPLE SENT TO MW
use "..\not_public\data0729.dta", clear
joinby respid using "..\not_public\sampleOnly.dta", unmatched(both) _merge(_merge)
keep if _merge==3
drop _merge

*MATCH IN GREBNER MEASURES
sort id
joinby id using "..\not_public\etovVH.dta", unmatched(both) _merge(_merge)
keep if _merge!=2
drop _merge

*MATCH IN NEW GREBNER VOTE HISTORY INFO
sort id
joinby id using "..\not_public\grebnerVHindicators.dta", unmatched(master) _merge(_merge)
drop _merge

drop xsurvnum respid fname lname phone qintro1 qintro2 qphone stopdate pin intgen fn1 zip fullphone
save "etov_replication.dta", replace

************************************
***CCES 2011 DATA ******************
************************************
clear all
set mem 500m
set more off
use "..\not_public\cces09_cmn_nomiss.dta", clear
keep cc09_07*
save "cces_replication.dta", replace




