******************************************************************
***PERSONALITY & PERSUASION REPLICATION FILE, SUBMITTED TO AJPS***
******************************************************************
clear all
set memory 100m
set more off

****************************************
***PERFORM SURVEY EXPERIMENT ANALYSIS***
****************************************
use mturk_replication.dta

*********
** RECODES
*********
*Only use if country is U.S.
drop if country!="United States"

*Informed consent given?
label var consent "Consent (1=yes)"

***Recodes
*Registered to vote
label var regvote "Registered to Vote in 2008? (1=yes)"

*Turnout
tab turnout08, gen(TO_)
gen voted08=TO_4
label var voted08 "Voted in 2008? (1=yes)"

*Vote disposition
gen votedisp08=.
replace votedisp08=1 if regvote==0 & voted08==0
replace votedisp08=2 if regvote==1 & voted08==0
replace votedisp08=3 if voted08==1
label var votedisp08 "Vote History Class (1=not reg; 2=reg/nonvoter; 3=voter)"

*Party ID
egen pid7=rmean(pid_dstr pid_rstr pid_lean)
label var pid7 "Party ID (-3=S Dem; 3=S Rep)"

*Ideology
replace ideology=0 if ideology==8
label var ideology "Ideology (-3=Extr Lib; 3=Extr Cons; DK=0)"

* Drop dropped treatments
gen clean_treat=0
replace clean_treat=1 if trt_socialpressure==1
replace clean_treat=2 if trt_duty==1
replace clean_treat=3 if trt_instrumental==1
label define treats 0 "Control" 1 "Social Pressure" 2 "Civic Duty" 3 "Instrumental Benefits" 
label values clean_treat treats

*Outcome
replace turnout_intent=(turnout_intent-1)/9
label var turnout_intent "Turnout Intent, 2010 (0-1)"

*Demographics
gen age=2010-yearofbirth
label var age "Age (in years)"
gen age2=(age*age)/100
label var age2 "Age-squared/100"
label var educ "Education (1=No HS; 6=post-grad)"
gen incomemis=(income==15)
replace income=14 if incomemis==1
label var income "Income (1=<10k; 14=>150k; 15=RF/Skipped)"
label var incomemis "Income missing"
replace r_other="1" if r_other!=""
destring r_other, replace
recast byte r_other
foreach i in white black hispanic asian nativeamer mixed other{
replace r_`i'=0 if r_`i'==.
replace r_`i'=1 if r_`i'!=0
label var r_`i' "`i' = 1"
}
replace r_other=r_asian+r_nativeamer+r_mixed+r_other
replace r_other=1 if r_other>1
label var r_other "Other race=1"
label var r_black "Black = 1"
label var r_hispanic "Hispanic = 1"
drop r_asian r_nativeamer r_mixed 

gen female=gender
label var female "Female=1"

***TIPI 
forvalues i=1/10{
rename tipi`i'a tipi`i'
}
*generate reverse-coded TIPI items
forvalues i=2(2)10{
gen tipi`i'_R=abs(tipi`i'-8)
}
gen BF_extraversion=(tipi1+tipi6_R)/2
gen BF_agreeableness=(tipi2_R+tipi7)/2
gen BF_conscientiousness=(tipi3+tipi8_R)/2
gen BF_stability=(tipi4_R+tipi9)/2
gen BF_openness=(tipi5+tipi10_R)/2

foreach i of var BF_*{
replace `i'=(`i'-1)/6
}
label var BF_extraversion "Extraversion"
label var BF_agreeableness "Agreeableness"
label var BF_conscientiousness "Conscientiousness"
label var BF_stability "Emotional Stability"
label var BF_openness "Openness"

*insample indicator
reg turnout_intent trt_* BF_* age age2 r_black r_hispanic r_other female educ income incomemis if votedisp==3
keep if e(sample)

foreach i in extraversion agreeableness conscientiousness stability openness{
egen BF_`i'_std=std(BF_`i')
}
label var BF_extraversion_std "Extraversion (standardized)"
label var BF_agreeableness_std "Agreeableness (standardized)"
label var BF_conscientiousness_std "Conscientiousness (standardized)"
label var BF_stability_std "Emotional Stability (standardized)"
label var BF_openness_std "Openness (standardized)"

*Personality x Treatment Interactions
foreach i of varlist trt_*{
foreach p in extraversion agreeableness conscientiousness stability openness{
local a=subinstr("`i'","trt_","",.)
local b=abbrev("`p'",6)
local b=subinstr("`b'","~","",.)
gen `a'X`b'= `i'*BF_`p'_std
local trtlabel : variable label `i'
local bflabel : variable label BF_`p'_std
local trtlabel=subinstr("`trtlabel'","Treatment: ","",.)
local trtlabel=subinstr("`trtlabel'"," (1=yes)","",.)
local bflabel=subinstr("`bflabel'"," (standardized)","",.)
label var `a'X`b' "`trtlabel' X `bflabel'"
}
}


*Demographics x Treatment Interactions
foreach i in age age2 r_black r_hispanic r_other female education income incomemis {
foreach p of varlist trt_* {
local b=subinstr("`p'","trt_","",.)
gen `i'X`b'= `i'*`p'
local ctrl : variable label `i'
local trtlabel: variable label `p'
local trtlabel=subinstr("`trtlabel'","Treatment: ","",.)
local trtlabel=subinstr("`trtlabel'"," (1=yes)","",.)
label var `i'X`b' "`ctrl' X `trtlabel'"
}
}

*********
** SUMMARY STATS: Table A1. Summary Statistics by Condition (Survey Experiment)
*********
sum turnout_intent BF_*_std age r_black r_hispanic r_other female education income incomemis, separator(0)
outsum age r_black r_hispanic r_other female education income incomemis turnout_intent using "logs\tableA1", bracket replace
outsum age r_black r_hispanic r_other female education income incomemis turnout_intent if control==1 using "logs\tableA1", bracket append ctitle(Control)
outsum age r_black r_hispanic r_other female education income incomemis turnout_intent if trt_social==1 using "logs\tableA1", bracket append ctitle(Social Pressure)
outsum age r_black r_hispanic r_other female education income incomemis turnout_intent if trt_duty==1 using "logs\tableA1", bracket append ctitle(Civic Duty)
outsum age r_black r_hispanic r_other female education income incomemis turnout_intent if trt_instrumental==1 using "logs\tableA1", bracket append ctitle(Instrumental Benefits)

outsum BF_extraversion BF_agreeableness BF_conscientiousness BF_stability BF_openness using "logs\table_A3", bracket replace

* Correlations between Big Five scale items
corr tipi1 tipi6_R 
corr tipi2_R tipi7 
corr tipi3 tipi8_R 
corr tipi4_R tipi9 
corr tipi5 tipi10_R 

mlogit clean_treat BF_*_std age r_black r_hispanic r_other female education income incomemis
foreach i in  BF_extraversion_std BF_agreeableness_std BF_conscientiousness_std BF_stability_std BF_openness_std age r_black r_hispanic r_other female education income incomemis{
test `i'
}


*********
** ANALYSIS: Table 2. Moderating Effects of Big Five Traits - Survey Experiment (column 1)
*********
reg turnout_intent trt_socialpressure trt_duty trt_instrumental socialpressureX* dutyX* instrumentalX* BF_*_std  age age2 r_black r_hispanic r_other female education income incomemis , r
test dutyXextrn dutyXagres dutyXconss dutyXstaby dutyXopens
local duty=r(p) 
test socialpressureXextrn socialpressureXagres socialpressureXconss socialpressureXstaby socialpressureXopens
local social=r(p) 
test instrumentalXextrn instrumentalXagres instrumentalXconss instrumentalXstaby instrumentalXopens
local instrumental=r(p) 
test dutyXextrn dutyXagres dutyXconss dutyXstaby dutyXopens socialpressureXextrn socialpressureXagres socialpressureXconss socialpressureXstaby socialpressureXopens instrumentalXextrn instrumentalXagres instrumentalXconss instrumentalXstaby instrumentalXopens
outreg trt_socialpressure trt_duty trt_instrumental socialpressureX* dutyX* instrumentalX* BF_*_std  age age2 r_black r_hispanic r_other female education income incomemis using "logs\table2", se bracket rdec(3) 3aster replace adec(7) addstat("Social Pressure interactions (Prob>F)", `social', "Duty interactions (Prob>F)", `duty', "Instrumental interactions (Prob>F)", `instrumental', "All interactions (Prob>F)", r(p))

** GENERATE DATA FOR FIGURE: Figure 1. Moderating Effects of Big Five Traits - Survey Experiment 
*********
foreach p in socialpressure duty instrumental {
foreach i in extraversion agreeableness conscientiousness stability openness{
local b=abbrev("`i'",6)
local b=subinstr("`b'","~","",.)
lincom `p'X`b'*2
matrix `i'=r(estimate)
matrix `i'_ci=r(se)*1.65
matrix `i'=`i',`i'_ci
if "`i'"=="extraversion"{
matrix mat_`p'=`i'
}
else{
matrix mat_`p'=mat_`p' \ `i'
}
}
}

**For additional estimates reported in the text
foreach p in socialpressure duty instrumental {
qui sum  turnout_intent
local sd=r(sd)
foreach i in extraversion agreeableness conscientiousness stability openness{
local b=abbrev("`i'",6)
local b=subinstr("`b'","~","",.)
lincom trt_`p' - `p'X`b'
lincom trt_`p' + `p'X`b'
qui lincom `p'X`b'*2
disp r(estimate)/`sd'
}
}
matrix graph_data=mat_socialpressure, mat_duty, mat_instrumental 
svmat graph_data, names(graph_data)
outsheet graph_data* using logs\figure1_data.csv,comma replace
drop graph_data*

*********
** ANALYSIS: Table 2. Moderating Effects of Big Five Traits - Survey Experiment (column 2)
*********
reg turnout_intent trt_socialpressure trt_duty trt_instrumental socialpressureX* dutyX* instrumentalX* BF_*_std  age* r_black* r_hispanic* r_other* female* education* income* , r
test dutyXextrn dutyXagres dutyXconss dutyXstaby dutyXopens
local duty=r(p) 
test socialpressureXextrn socialpressureXagres socialpressureXconss socialpressureXstaby socialpressureXopens
local social=r(p) 
test instrumentalXextrn instrumentalXagres instrumentalXconss instrumentalXstaby instrumentalXopens
local instrumental=r(p) 
test dutyXextrn dutyXagres dutyXconss dutyXstaby dutyXopens socialpressureXextrn socialpressureXagres socialpressureXconss socialpressureXstaby socialpressureXopens instrumentalXextrn instrumentalXagres instrumentalXconss instrumentalXstaby instrumentalXopens
outreg trt_socialpressure trt_duty trt_instrumental socialpressureX* dutyX* instrumentalX* BF_*_std  age age2 r_black r_hispanic r_other female education income incomemis using "logs\table2.out", se bracket rdec(3) 3aster append adec(7) addstat("Social Pressure interactions (Prob>F)", `social', "Duty interactions (Prob>F)", `duty', "Instrumental interactions (Prob>F)", `instrumental', "All interactions (Prob>F)", r(p))


***************************************************
** CCES CORRELATIONS ******************************
***************************************************
clear all
set mem 500m
use "cces_replication.dta", clear
***TIPI 
recode cc09_07a cc09_07b cc09_07c cc09_07d cc09_07e cc09_07f cc09_07g cc09_07h cc09_07i cc09_07j (1=1) (2=2) (3=3) (4=4) (5=5) (6=6) (7=7) (*=.), gen(_b_p_extraverted _b_p_critical _b_p_dependable _b_p_anxious _b_p_open _b_p_reserved _b_p_sympathetic _b_p_disorganized _b_p_calm _b_p_conventional)
*reverse code
recode _b_p_disorganized _b_p_conventional _b_p_critical _b_p_anxious _b_p_reserved (7=1) (6=2) (5=3) (4=4) (3=5) (2=6) (1=7) (*=.), gen(_b_p_disorganized_R _b_p_conventional_R _b_p_critical_R _b_p_anxious_R _b_p_reserved_R)

*Items range from 0 to 1 -- higher values indicate more of the trait
*Big Five - conscientiousness
gen BF_conscientiousness = (_b_p_dependable + _b_p_disorganized_R)/2
*Big Five - openness to experiences
gen BF_openness = (_b_p_open + _b_p_conventional_R)/2
*Big Five - agreeableness
gen BF_agreeableness = (_b_p_sympathetic + _b_p_critical_R)/2
*Big Five - emotional stability
gen BF_stability = (_b_p_calm + _b_p_anxious_R)/2
*Big Five - extraversion
gen BF_extraversion = (_b_p_extraverted + _b_p_reserved_R)/2

label var BF_extraversion "Extraversion"
label var BF_agreeableness "Agreeableness"
label var BF_conscientiousness "Conscientiousness"
label var BF_stability "Emotional Stability"
label var BF_openness "Openness"

*insample indicator
reg BF_* 
keep if e(sample)
foreach i of var BF_*{
replace `i'=(`i'-1)/6
}
corr BF_* 
outsum BF_extraversion BF_agreeableness BF_conscientiousness BF_stability BF_openness using "logs\table_A3", bracket append


**********************************************************************************************
************************************######### FIELD EXPERIMENT ########***********************
**********************************************************************************************
clear all
use "etov_replication.dta"
*******************
*** ETOV RECODES***
*******************

*** TIPI
****************************
**CONSTRUCT BIG FIVE ITEMS**
****************************

*personality - extraverted
rename q1_1 p_extraverted

*personality - critical 
rename q1_2 p_critical

*personality - dependable
rename q1_3 p_dependable

*personality - anxious
rename q1_4 p_anxious

*personality - open to new experiences
rename q1_5 p_open

*personality - reserved
rename q1_6 p_reserved

*personality - sympathetic
rename q1_7 p_sympathetic

*personality - disorganized
rename q1_8 p_disorganized

*personality - calm
rename q1_9 p_calm

*personality - conventional
rename q1_10 p_conventional


*Items range from 0 to 1 -- higher values mean more of the trait
recode p_* (6=.)

*Big Five - extraversion

recode p_reserved (5=1) (4=2) (3=3) (2=4) (1=5), gen(p_reserved_R)
gen BF_extraversion = (((p_extraverted + p_reserved_R)/2)-1)/4
label var BF_extraversion "Extraversion (0-1)"

*Big Five - agreeableness

recode p_critical (5=1) (4=2) (3=3) (2=4) (1=5), gen(p_critical_R)
gen BF_agreeableness = (((p_sympathetic + p_critical_R)/2)-1)/4
label var BF_agreeableness "Agreeableness (0-1)"

*Big Five - conscientiousness

recode p_disorganized (5=1) (4=2) (3=3) (2=4) (1=5), gen(p_disorganized_R)
gen BF_conscientiousness = (((p_dependable + p_disorganized_R)/2)-1)/4
label var BF_conscientiousness "Conscientiousness (0-1)"

*Big Five - emotional stability

recode p_anxious (5=1) (4=2) (3=3) (2=4) (1=5), gen(p_anxious_R)
gen BF_stability = (((p_calm + p_anxious_R)/2)-1)/4
label var BF_stability "Stability (0-1)"

*Big Five - openness to experiences

recode p_conventional (5=1) (4=2) (3=3) (2=4) (1=5), gen(p_conventional_R)
gen BF_openness = (((p_open + p_conventional_R)/2)-1)/4
label var BF_openness "Openness (0-1)"

corr p_extraverted p_reserved_R
corr p_sympathetic p_critical_R
corr p_dependable p_disorganized_R
corr p_calm p_anxious_R
corr p_open p_conventional_R

*Reported turnout 2006
gen rep2006=(q6==1)
label var rep2006 "Say Voted in 2006 General"

*Misreport turning out in 2006 general
gen lie2006 = (rep2006==1 & g2006==0)

*Reported turnout 2008
gen rep2008=(q3==1)
label var rep2008 "Say Voted in 2008 General"

*Misreport turning out in 2008 general
gen lie2008 = (rep2008==1 & g2008==0)


*DEMOGRAPHICS
*HH-Size
drop if hh_size>2
replace hh_size=hh_size-1
gen c0_hh_size=hh_size 
label var c0_hh_size "Household Size (0=1-person; 1=2-person)"

*Age
destring yob1, replace
replace yob1=yob1+1900
replace yob=yob1 if yob==.
gen c1_age=2006-yob
label var c1_age "Age (in years)"
gen c1_age2=c1_age^2/100
label var c1_age2 "Age-squared/100"

*Gender
gen c1_gender = 1 if q22 ==2
replace c1_gender = 0 if q22 ==1
label var c1_gender "Female=1"

*Race
rename q13r1 race
gen c1_white = 0 if race ~=.
replace c1_white = 1 if race==1
label var c1_white "White = 1"
gen black = 0 if race ~=.
replace black = 1 if race==2
label var black "Black = 1"
gen otherrace = 0 if race ~=.
replace otherrace = 1 if race==3
replace otherrace = 1 if race==4
replace otherrace = 1 if race==5
replace otherrace = 1 if race==6
replace otherrace = 1 if race==7
replace otherrace = 1 if race==8
label var otherrace "Other (Hispanic,Native American,Asian,Mixed,Other) = 1"

*Education
recode q14 (6 7=.), gen(educ)
label var educ "Education (1=No HS; 5=post-grad)"
gen c2_educ=educ
label var c2_educ "Education (1=No HS; 5=post-grad)"
/*
tab educ, gen(c2_educD)
drop c2_educD2
label var c2_educD1 "No HS diploma"
label var c2_educD3 "Some College"
label var c2_educD4 "4-year College degree"
label var c2_educD5 "Postgraduate degree"
*/

*Family Income
gen c2_income=q15
gen c2_incomemis = 0
replace c2_incomemis = 1 if c2_income==10 | c2_income==11 | c2_income==.
label var c2_incomemis "Income missing"
replace c2_income = 10 if c2_incomemis==1
label var c2_income "Income (1=<10k; 9=>150k; 10=RF/DK)"

*Religious Services Frequency
recode q16 (7=0) (6=1) (5=2) (4=3) (3=4) (2=5) (1=6) (*=.), gen(c2_religatt)
label var c2_religatt "Religious attendance, 1=Never; 6=>More than once a week"

*Reported Age
gen repage = q17_2 if q17_1 ==.
replace repage  = (2009-q17_1)
label var repage "Reported Age, in years"

*PID
recode q7 (1=-1) (2=1) (3=0) (*=.), gen(pid3)
gen pid7=pid3*2
replace pid7=pid7*1.5 if q8==1
replace pid7=-1 if q9==1
replace pid7=1 if q9==2
label var pid7 "Party ID (-3=St. R; 3=St. D)"

tab pid7, gen(c3_PID)
drop c3_PID4
label var c3_PID1 "Strong Republican"
label var c3_PID2 "Weak Republican"
label var c3_PID3 "Leaning Republican"
label var c3_PID5 "Leaning Democrat"
label var c3_PID6 "Weak Democrat"
label var c3_PID7 "Strong Democrat"

gen strpid=abs(pid7)
label var strpid "Strength of PID (0-3)"

*Ideology
recode q10 (6 7=.), gen(ideology1)
replace ideology1=(ideology1-3)*-1
label var ideology1 "Ideology (-2=v cons; 2=v lib) - DK=Miss"

gen c3_ideology=ideology1
replace c3_ideology=0 if q10>5
label var c3_ideology "Ideology (-2=v cons; 2=v lib) - DK=Moderate"

gen c4_p2002=p2002
gen c4_g2002=g2002
label var c4_p2002 "Primary Turnout: 2002"
label var c4_g2002 "General Turnout: 2002"


*** RESTRICT SAMPLE
logit p2006 neighbor BF_* c1_age c1_age2 c1_gender c2_educ c2_income c2_incomemis c1_white c0_hh_size, r
gen insample=e(sample)
*** ENSURE SAMPLE MATCHES CHARACTERISTICS USED IN Gerber et al
replace insample=0 if dem>58
replace insample=0 if aug<30
replace insample=0 if aug>80

** output summary stats for BF (prestandardization)
label var BF_extraversion "Extraversion"
label var BF_agreeableness "Agreeableness"
label var BF_conscientiousness "Conscientiousness"
label var BF_stability "Emotional Stability"
label var BF_openness "Openness"


*Standardize Big 5
foreach i in extraversion agreeableness conscientiousness stability openness{
egen std_BF_`i'=std(BF_`i') if insample==1
replace BF_`i'=std_BF_`i'
}
label var BF_extraversion "Extraversion (standardized)"
label var BF_agreeableness "Agreeableness (standardized)"
label var BF_conscientiousness "Conscientiousness (standardized)"
label var BF_stability "Emotional Stability (standardized)"
label var BF_openness "Openness (standardized)"

foreach i in extraversion agreeableness conscientiousness stability openness{
gen BFXN_`i'=BF_`i'*neighbor
}
label var BFXN_extraversion "Social Pressure X Extraversion"
label var BFXN_agreeableness "Social Pressure X Agreeableness"
label var BFXN_conscientiousness "Social Pressure X Conscientiousness"
label var BFXN_stability "Social Pressure X Emotional Stability"
label var BFXN_openness "Social Pressure X Openness"
label var neighbor "Treatment: Social Pressure (1=yes)"

foreach i of varlist c*_* {
foreach bf of varlist BF_* {
local b=subinstr("`bf'","BF_","",.)
gen b_`i'X`b'=`i'*`bf'
local ilabel : variable label `i'
local bflabel : variable label `bf'
label var b_`i'X`b' "`ilabel' x `bflabel'"
}
}

**Demographics x Treatment
foreach i of varlist c*_* {
gen `i'Xneighbor=`i'*neighbor
local label : variable label `i'
label var `i'Xneighbor "Social Pressure x `label'"
}

**Household Size x Treatment x Big Five
foreach bf of varlist BF_* {
local b=subinstr("`bf'","BF_","",.)
gen threeway_`b'=c0_hh_size*neighbor*`bf'
local bflabel : variable label `bf'
label var threeway_`b' "Social Pressure x HH size x `bflabel'"
}

**Household Size x Big Five
foreach bf of varlist BF_* {
local b=subinstr("`bf'","BF_","",.)
gen hh_`b'=c0_hh_size*`bf'
local bflabel : variable label `bf'
label var hh_`b' "HH size (0=1-person; 1=2-person) x `bflabel'"
}


keep if insample 

*********
** SUMMARY STATS: Table A4. Summary Statistics by Condition (Field Experiment)
*********
logit neighbor c1_age c1_gender c1_white c2_educ c2_income c2_incomemis 
outsum c1_age c1_gender c1_white c2_educ c2_income c2_incomemis p2006 using "logs\tableA4", bracket replace
outsum c1_age c1_gender c1_white c2_educ c2_income c2_incomemis p2006 if neighbor==0 using "logs\tableA4", bracket append ctitle(Control)
outsum c1_age c1_gender c1_white c2_educ c2_income c2_incomemis p2006 if neighbor==1 using "logs\tableA4", bracket append ctitle(Treatment)

*********
** SUMMARY STATS: Table A6. Balance by Household Size - Field Experiment
*********
logit neighbor c1_age c1_gender c1_white c2_educ c2_income c2_incomemis if hh_size==0
outsum c1_age c1_gender c1_white c2_educ c2_income c2_incomemis p2006 if hh_size==0 using "logs\tableA6", bracket replace
outsum c1_age c1_gender c1_white c2_educ c2_income c2_incomemis p2006 if hh_size==0 & neighbor==0 using "logs\tableA6", bracket append ctitle(Control)
outsum c1_age c1_gender c1_white c2_educ c2_income c2_incomemis p2006 if hh_size==0 & neighbor==1 using "logs\tableA6", bracket append ctitle(Treatment)

logit neighbor c1_age c1_gender c1_white c2_educ c2_income c2_incomemis if hh_size==1
outsum c1_age c1_gender c1_white c2_educ c2_income c2_incomemis p2006 if hh_size==1 using "logs\tableA6", bracket append
outsum c1_age c1_gender c1_white c2_educ c2_income c2_incomemis p2006 if hh_size==1 & neighbor==0 using "logs\tableA6", bracket append ctitle(Control)
outsum c1_age c1_gender c1_white c2_educ c2_income c2_incomemis p2006 if hh_size==1 & neighbor==1 using "logs\tableA6", bracket append ctitle(Treatment)

*********
** MAIN ANALYSIS: Table 3. Moderating Effects of Big Five Traits - Field Experiment
*********
reg p2006 neighbor BF_* BFXN* c0_hh_size c1_age c1_age2 c1_gender c1_white c2_educ c2_income c2_incomemis
test BFXN_extraversion BFXN_agreeableness BFXN_conscientiousness BFXN_stability BFXN_openness
local social=r(p)
outreg neighbor BF_* BFXN* c0_hh_size c1_age c1_age2 c1_gender c1_white c2_educ c2_income c2_incomemis using "logs\table3.out", se bracket 3aster replace ctitle(All HHs) rdec(3) adec(7) addstat("Social Pressure interactions (Prob>F)", `social')
reg p2006 neighbor BF_* BFXN* c1_age c1_age2 c1_gender c1_white c2_educ c2_income c2_incomemis if insample==1 & hh_size==0, r
test BFXN_extraversion BFXN_agreeableness BFXN_conscientiousness BFXN_stability BFXN_openness
local social=r(p)
outreg neighbor BF_* BFXN* c1_age c1_age2 c1_gender c1_white c2_educ c2_income c2_incomemis using "logs\table3.out", se bracket 3aster append ctitle(1-Voter HHs) rdec(3) adec(7) addstat("Social Pressure interactions (Prob>F)", `social')
reg p2006 neighbor BF_* BFXN* c1_age c1_age2 c1_gender c1_white c2_educ c2_income c2_incomemis if insample==1 & hh_size==1, r
test BFXN_extraversion BFXN_agreeableness BFXN_conscientiousness BFXN_stability BFXN_openness
local social=r(p)
outreg neighbor BF_* BFXN* c1_age c1_age2 c1_gender c1_white c2_educ c2_income c2_incomemis using "logs\table3.out", se bracket 3aster append ctitle(2-Voter HHs) rdec(3) adec(7) addstat("Social Pressure interactions (Prob>F)", `social')
reg p2006 neighbor BF_* BFXN* threeway_* hh_extraversion hh_agreeableness hh_conscientiousness hh_stability hh_openness c0_hh_size c1_age c1_age2 c1_gender c1_white c2_educ c2_income c2_incomemis if insample==1, r
test threeway_extraversion threeway_agreeableness threeway_conscientiousness threeway_stability threeway_openness
local threeway=r(p)
outreg neighbor BF_* BFXN* hh_extraversion hh_agreeableness hh_conscientiousness hh_stability hh_openness threeway_* c0_hh_size c1_age c1_age2 c1_gender c1_white c2_educ c2_income c2_incomemis using "logs\table3.out", se bracket 3aster append ctitle(All HHs) rdec(3) adec(7) addstat("Three Way interactions (Prob>F)", `threeway')

reg p2006 neighbor BF_* BFXN* c0_hh_size c1_* c2_* if insample==1, r
test BFXN_extraversion BFXN_agreeableness BFXN_conscientiousness BFXN_stability BFXN_openness
local social=r(p)
outreg neighbor BF_* BFXN* c0_hh_size c1_age c1_age2 c1_gender c1_white c2_educ c2_income c2_incomemis using "logs\table3.out", se bracket 3aster append ctitle(All HHs: Demographic Interactions) rdec(3) adec(7) addstat("Social Pressure interactions (Prob>F)", `social')
reg p2006 neighbor BF_* BFXN* c1_* c2_* if insample==1 & hh_size==0, r
test BFXN_extraversion BFXN_agreeableness BFXN_conscientiousness BFXN_stability BFXN_openness
local social=r(p)
outreg neighbor BF_* BFXN* c1_age c1_age2 c1_gender c1_white c2_educ c2_income c2_incomemis using "logs\table3.out", se bracket 3aster append ctitle(1-Voter HHs: Demographic Interactions) rdec(3) adec(7) addstat("Social Pressure interactions (Prob>F)", `social')
reg p2006 neighbor BF_* BFXN* c1_* c2_* if insample==1 & hh_size==1, r
test BFXN_extraversion BFXN_agreeableness BFXN_conscientiousness BFXN_stability BFXN_openness
local social=r(p)
outreg neighbor BF_* BFXN* c1_age c1_age2 c1_gender c1_white c2_educ c2_income c2_incomemis using "logs\table3.out", se bracket 3aster append ctitle(2-Voter HHs: Demographic Interactions) rdec(3) adec(7) addstat("Social Pressure interactions (Prob>F)", `social')
reg p2006 neighbor BF_* BFXN* threeway_* hh_extraversion hh_agreeableness hh_conscientiousness hh_stability hh_openness c0_hh_size c1_* c2_* if insample==1 , r
test threeway_extraversion threeway_agreeableness threeway_conscientiousness threeway_stability threeway_openness
local threeway=r(p)
outreg neighbor BF_* BFXN* threeway_* hh_extraversion hh_agreeableness hh_conscientiousness hh_stability hh_openness c0_hh_size c1_age c1_age2 c1_gender c1_white c2_educ c2_income c2_incomemis using "logs\table3.out", se bracket 3aster append ctitle(All HHs: Demographic Interactions) rdec(3) adec(7) addstat("Three Way interactions (Prob>F)", `threeway')

reg p2006 neighbor BF_* BFXN* c1_age c1_age2 c1_gender c1_white c2_educ c2_income c2_incomemis if insample==1 & hh_size==0, r
foreach i in extraversion agreeableness conscientiousness stability openness {
qui lincom neighbor-BFXN_`i'
matrix `i'_est=r(estimate)
matrix `i'_ci=r(se)*1.65
qui lincom neighbor+BFXN_`i'
matrix `i'_est=`i'_est,r(estimate)
matrix `i'_ci=`i'_ci,r(se)*1.65
matrix `i'_full=`i'_est,`i'_ci
if "`i'"=="extraversion" {
matrix etov_ests=`i'_full
}
else{
matrix etov_ests=etov_ests \ `i'_full
}
}

svmat etov_ests, names(etov_ests)
outsheet etov_ests* using logs\etov_ests.csv,comma replace
drop etov_ests*

*********
** LOGIT ROBUSTNESS: Table A5. Moderating Effects of Big Five Traits - Field Experiment (Logit)
*********
logit p2006 neighbor BF_* BFXN* c0_hh_size c1_age c1_age2 c1_gender c1_white c2_educ c2_income c2_incomemis if insample==1, r
test BFXN_extraversion BFXN_agreeableness BFXN_conscientiousness BFXN_stability BFXN_openness
local social=r(p)
outreg neighbor BF_* BFXN* c0_hh_size c1_age c1_age2 c1_gender c1_white c2_educ c2_income c2_incomemis using "logs\tableA5.out", se bracket 3aster replace ctitle(All HHs) rdec(3) adec(7) addstat("Social Pressure interactions (Prob>F)", `social')
logit p2006 neighbor BF_* BFXN* c1_age c1_age2 c1_gender c1_white c2_educ c2_income c2_incomemis if insample==1 & hh_size==0, r
test BFXN_extraversion BFXN_agreeableness BFXN_conscientiousness BFXN_stability BFXN_openness
local social=r(p)
outreg neighbor BF_* BFXN* c1_age c1_age2 c1_gender c1_white c2_educ c2_income c2_incomemis using "logs\tableA5.out", se bracket 3aster append ctitle(1-Voter HHs) rdec(3) adec(7) addstat("Social Pressure interactions (Prob>F)", `social')
logit p2006 neighbor BF_* BFXN* c1_age c1_age2 c1_gender c1_white c2_educ c2_income c2_incomemis if insample==1 & hh_size==1, r
test BFXN_extraversion BFXN_agreeableness BFXN_conscientiousness BFXN_stability BFXN_openness
local social=r(p)
outreg neighbor BF_* BFXN* c1_age c1_age2 c1_gender c1_white c2_educ c2_income c2_incomemis using "logs\tableA5.out", se bracket 3aster append ctitle(2-Voter HHs) rdec(3) adec(7) addstat("Social Pressure interactions (Prob>F)", `social')
logit p2006 neighbor BF_* BFXN* threeway_* hh_extraversion hh_agreeableness hh_conscientiousness hh_stability hh_openness c0_hh_size c1_age c1_age2 c1_gender c1_white c2_educ c2_income c2_incomemis if insample==1, r
test threeway_extraversion threeway_agreeableness threeway_conscientiousness threeway_stability threeway_openness
local threeway=r(p)
outreg neighbor BF_* BFXN* hh_extraversion hh_agreeableness hh_conscientiousness hh_stability hh_openness threeway_* c0_hh_size c1_age c1_age2 c1_gender c1_white c2_educ c2_income c2_incomemis using "logs\tableA5.out", se bracket 3aster append ctitle(All HHs) rdec(3) adec(7) addstat("Three Way interactions (Prob>F)", `threeway')

logit p2006 neighbor BF_* BFXN* c0_hh_size c1_* c2_* if insample==1, r
test BFXN_extraversion BFXN_agreeableness BFXN_conscientiousness BFXN_stability BFXN_openness
local social=r(p)
outreg neighbor BF_* BFXN* c0_hh_size c1_age c1_age2 c1_gender c1_white c2_educ c2_income c2_incomemis using "logs\tableA5.out", se bracket 3aster append ctitle(All HHs: Demographic Interactions) rdec(3) adec(7) addstat("Social Pressure interactions (Prob>F)", `social')
logit p2006 neighbor BF_* BFXN* c1_* c2_* if insample==1 & hh_size==0, r
test BFXN_extraversion BFXN_agreeableness BFXN_conscientiousness BFXN_stability BFXN_openness
local social=r(p)
outreg neighbor BF_* BFXN* c1_age c1_age2 c1_gender c1_white c2_educ c2_income c2_incomemis using "logs\tableA5.out", se bracket 3aster append ctitle(1-Voter HHs: Demographic Interactions) rdec(3) adec(7) addstat("Social Pressure interactions (Prob>F)", `social')
logit p2006 neighbor BF_* BFXN* c1_* c2_* if insample==1 & hh_size==1, r
test BFXN_extraversion BFXN_agreeableness BFXN_conscientiousness BFXN_stability BFXN_openness
local social=r(p)
outreg neighbor BF_* BFXN* c1_age c1_age2 c1_gender c1_white c2_educ c2_income c2_incomemis using "logs\tableA5.out", se bracket 3aster append ctitle(2-Voter HHs: Demographic Interactions) rdec(3) adec(7) addstat("Social Pressure interactions (Prob>F)", `social')
logit p2006 neighbor BF_* BFXN* threeway_* hh_extraversion hh_agreeableness hh_conscientiousness hh_stability hh_openness c0_hh_size c1_* c2_* if insample==1 , r
test threeway_extraversion threeway_agreeableness threeway_conscientiousness threeway_stability threeway_openness
local threeway=r(p)
outreg neighbor BF_* BFXN* threeway_* hh_extraversion hh_agreeableness hh_conscientiousness hh_stability hh_openness c0_hh_size c1_age c1_age2 c1_gender c1_white c2_educ c2_income c2_incomemis using "logs\tableA5.out", se bracket 3aster append ctitle(All HHs: Demographic Interactions) rdec(3) adec(7) addstat("Three Way interactions (Prob>F)", `threeway')
